#!/bin/bash

# Some information
# https://www.justboom.co/tutorials/configure-justboom-ir-remote-lirc/
# https://www.max2play.com/en/forums/topic/infrared-remote-for-max2play-rpi-squeezebox/

# Keymap lirc-x jivelite:  /usr/share/doc/lirc/irxevent.keys

# Use irw to test the remote

CURRENTDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
USER=$(grep -a "SYSTEM_USER" /opt/max2play/audioplayer.conf | sed -n -e 's/^[A-Z_]*\=//p')

###### ---- 3 Options Available---- ###########
# Setup lirc in /boot/config.txt with PHP First (use function in RaspberryPi settings, add IR to RaspberryPi Settings)!

if [ -e /etc/lirc/lirc_options.conf ]; then
	# New Lirc 0.9.4 Version Updates
	sed -i 's@^driver.*=.*@driver=default@;s@^device.*=.*@device=/dev/lirc0@' /etc/lirc/lirc_options.conf
	if [ -e /etc/lirc/lircd.conf.d/lircd.conf ]; then
		echo "Config File lircd.conf already existing" 
	else
		# make sure original path of new lirc version is included
		cp -f /etc/lirc/lircd.conf.dist /etc/lirc/lircd.conf
		cp $CURRENTDIR/ir/lircd.conf /etc/lirc/lircd.conf.d/
		chmod 777 /etc/lirc/lircd.conf.d/lircd.conf
	fi
else
	# Copy initial lirc remote configuration (IR-Code definition)
	if [ "$(grep -i 'begin remote' /etc/lirc/lircd.conf | wc -l)" -lt "1" ]; then 
		cp $CURRENTDIR/ir/lircd.conf /etc/lirc/
		chmod 777 /etc/lirc/lircd.conf
	fi
	# Edit /etc/lirc/hardware.conf
	sed -i 's@^LIRCD_ARGS=.*@LIRCD_ARGS="--uinput"@;s@^DRIVER=.*@DRIVER="default"@;s@^DEVICE=.*@DEVICE="/dev/lirc0"@;s@^MODULES=.*@MODULES="lirc_rpi"@' /etc/lirc/hardware.conf
fi

# Remove any existing configuration!
if [ -e /opt/max2play/custom_autostart.sh ]; then
    sed -i 's/.*\/ir\/my_lirc.*//' /opt/max2play/custom_autostart.sh
fi
sed -i 's@ -i .*\/ir\/my_lircsqueeze@@' /opt/max2play/audioplayer.conf


###### 1. Jivelite
if [ "$1" == "jivelite" ]; then     
    # Use irxevent and lircjivelite config
    if [ "$(dpkg -s lirc-x | grep 'install ok' | wc -l)" -lt "1" ]; then
	    apt-get update
	    apt-get install lirc-x --yes --force-yes
	fi
    
    if [ ! -e $CURRENTDIR/ir/my_lircjivelite ]; then
    	cp $CURRENTDIR/ir/lircjivelite $CURRENTDIR/ir/my_lircjivelite
    fi
    
    # Add irxevent to custom autostart under user pi and exported Display
    
    if [ ! -e /opt/max2play/custom_autostart.sh ]; then
		echo -e "#!/bin/bash\nif [ \"\$(ps -Al | grep irxevent | wc -l)\" -lt \"1\" ]; then export DISPLAY=:0;sudo su -l $USER -c \"irxevent -d $CURRENTDIR/ir/my_lircjivelite\";fi\n" >> /opt/max2play/custom_autostart.sh
		chmod 777 /opt/max2play/custom_autostart.sh
	else
		echo -e "\nif [ \"\$(ps -Al | grep irxevent | wc -l)\" -lt \"1\" ]; then export DISPLAY=:0;sudo su -l $USER -c \"irxevent -d $CURRENTDIR/ir/my_lircjivelite\";fi\n" >> /opt/max2play/custom_autostart.sh
		chmod 777 /opt/max2play/custom_autostart.sh
	fi
	echo "Jivelite lirc configuration finished";
fi


###### 2. Squeezelite
if [ "$1" == "squeezelite" ]; then     
    if [ ! -e $CURRENTDIR/ir/my_lircsqueezelite ]; then
    	cp $CURRENTDIR/ir/lircsqueezelite $CURRENTDIR/ir/my_lircsqueezelite
    fi
    
    # add Parameter -i to Squeezelite with Path to lircsqueeze
    SQUEEZELITE_PARAMETER=$(grep -a "SQUEEZELITE_PARAMETER" /opt/max2play/audioplayer.conf | sed -n -e 's/^[A-Z_]*\=//p')    
    sed -i "s@^SQUEEZELITE_PARAMETER=.*@SQUEEZELITE_PARAMETER=$SQUEEZELITE_PARAMETER -i $CURRENTDIR/ir/my_lircsqueezelite@" /opt/max2play/audioplayer.conf
    echo "Squeezelite lirc configuration finished";
fi


###### 3. MPD
if [ "$1" == "mpd" ]; then 
    
    # use lircmpd config and irexec    
    # add irexec to custom autostart
    
    if [ ! -e $CURRENTDIR/ir/my_lircmpd ]; then
    	cp $CURRENTDIR/ir/lircmpd $CURRENTDIR/ir/my_lircmpd
    fi
    
    if [ ! -e /opt/max2play/custom_autostart.sh ]; then
		echo -e "#!/bin/bash\nif [ \"\$(ps -Al | grep irexec | wc -l)\" -lt \"1\" ]; then sudo su -l $USER -c \"irexec -d $CURRENTDIR/ir/my_lircmpd\";fi\n" >> /opt/max2play/custom_autostart.sh
		chmod 777 /opt/max2play/custom_autostart.sh
	else
		echo -e "\nif [ \"\$(ps -Al | grep irexec | wc -l)\" -lt \"1\" ]; then sudo su -l $USER -c \"irexec -d $CURRENTDIR/ir/my_lircmpd\";fi\n" >> /opt/max2play/custom_autostart.sh
		chmod 777 /opt/max2play/custom_autostart.sh
	fi
	echo "MPD lirc configuration finished";
fi

###### 4. Kodi
if [ "$1" == "kodi" ]; then         
    
    if [ ! -e /home/pi/.kodi/userdata/Lircmap.xml ]; then
    	ln /var/www/max2play/application/plugins/justboom/scripts/ir/lirckodi /home/pi/.kodi/userdata/Lircmap.xml
    fi    
    if [ ! -e $CURRENTDIR/ir/my_lirckodi ]; then
    	cp $CURRENTDIR/ir/lirckodi $CURRENTDIR/ir/my_lirckodi
    fi
	echo "Kodi lirc configuration finished";
fi

chmod -R 777 $CURRENTDIR/ir/

killall irexec;killall irxevent;

echo "";

echo "finished - Reboot needed: <b><a href='/plugins/max2play_settings/controller/Basic.php?action=reboot&redirecturl=/plugins/justboom/controller/Setup.php'>Click here to Restart Device</a></b>";

exit 0